@@ -9,12 +9,12 @@ void Particles_initialize_rand_gen(ParticlesData particles,
 
 	 uint32_t s1, s2, s3, s;
 	 s = seeds[ii];
-         
+
 	 rng_set(&s1, &s2, &s3, s);
 
-	 ParticlesData_set___rng_s1(particles, ii, s1);
-	 ParticlesData_set___rng_s2(particles, ii, s2);
-	 ParticlesData_set___rng_s3(particles, ii, s3);
+	 ParticlesData_set__rng_s1(particles, ii, s1);
+	 ParticlesData_set__rng_s2(particles, ii, s2);
+	 ParticlesData_set__rng_s3(particles, ii, s3);
 
      }//end_vectorize
 
